@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION @EXPORT @EXPORT_OK @ISA $CurrentPackage @IncludeLibs $ScanFileRE );
 
-$VERSION   = '1.04';
+$VERSION   = '1.05';
 @EXPORT    = qw( scan_deps scan_deps_runtime );
 @EXPORT_OK = qw( scan_line scan_chunk add_deps scan_deps_runtime path_to_inc_name );
 
@@ -275,6 +275,7 @@ my %Preload;
                 _glob_in_inc('Date/Manip/Offset', 1));
     },
     'DateTime/Locale.pm' => 'sub',
+    'DateTime/TimeZone.pm' => 'sub',
     'DBI.pm' => sub {
         grep !/\bProxy\b/, _glob_in_inc('DBD', 1);
     },
@@ -355,21 +356,40 @@ my %Preload;
         _glob_in_inc('$CurrentPackage/Plugin', 1);
     },
     'MIME/Decoder.pm'               => 'sub',
+    'Moose.pm'                      => sub {
+        _glob_in_inc('Moose', 1),
+        _glob_in_inc('Class/MOP', 1),
+    },
+    'MooseX/AttributeHelpers.pm'    => 'sub',
+    'MooseX/POE.pm'                 => sub {
+        _glob_in_inc('MooseX/POE', 1),
+        _glob_in_inc('MooseX/Async', 1),
+    },
+    'MozRepl.pm'                    => sub {
+        qw( MozRepl/Log.pm MozRepl/Client.pm Module/Pluggable/Fast.pm ),
+        _glob_in_inc('MozRepl/Plugin', 1),
+    },
     'Net/DNS/RR.pm'                 => 'sub',
     'Net/FTP.pm'                    => 'sub',
     'Net/Server.pm'                 => 'sub',
     'Net/SSH/Perl.pm'               => 'sub',
+    'Package/Stash.pm'              => [qw( Package/Stash/PP.pm Package/Stash/XS.pm )],
     'PAR/Repository.pm'             => 'sub',
     'PAR/Repository/Client.pm'      => 'sub',
+    'Parse/AFP.pm'                  => 'sub',
+    'Parse/Binary.pm'               => 'sub',
     'Perl/Critic.pm'                => 'sub', #not only Perl/Critic/Policy
+    'PerlIO.pm'                     => [ 'PerlIO/scalar.pm' ],
     'PDF/API2/Resource/Font.pm'     => 'sub',
     'PDF/API2/Basic/TTF/Font.pm'    => sub {
         _glob_in_inc('PDF/API2/Basic/TTF', 1);
     },
     'PDF/Writer.pm'                 => 'sub',
-    'POE.pm'                           => [ qw(
-        POE/Kernel.pm POE/Session.pm
-    ) ],
+    'POE.pm'                        => [qw( POE/Kernel.pm POE/Session.pm )],
+    'POE/Component/Client/HTTP.pm'  => sub {
+        _glob_in_inc('POE/Component/Client/HTTP', 1),
+        qw( POE/Filter/HTTPChunk.pm POE/Filter/HTTPHead.pm ),
+    },
     'POE/Kernel.pm'                    => sub {
         _glob_in_inc('POE/XS/Resource', 1),
         _glob_in_inc('POE/Resource', 1),
@@ -382,9 +402,6 @@ my %Preload;
             } qw( SigAction SigRt )
     },
     'PPI.pm'                        => 'sub',
-    'Parse/AFP.pm'                  => 'sub',
-    'Parse/Binary.pm'               => 'sub',
-    'PerlIO.pm'                     => [ 'PerlIO/scalar.pm' ],
     'Regexp/Common.pm'              => 'sub',
     'RPC/XML/ParserFactory.pm'      => sub {
         _glob_in_inc('RPC/XML/Parser', 1);
@@ -393,8 +410,11 @@ my %Preload;
         termios.ph asm/termios.ph sys/termiox.ph sys/termios.ph sys/ttycom.ph
     ) ],
     'SOAP/Lite.pm'                  => sub {
-        (($] >= 5.008 ? ('utf8.pm') : ()), _glob_in_inc('SOAP/Transport', 1));
+        ($] >= 5.008 ? ('utf8.pm') : ()), 
+        _glob_in_inc('SOAP/Transport', 1),
+        _glob_in_inc('SOAP/Lite/Deserializer', 1),
     },
+    'Socket/GetAddrInfo.pm'         => 'sub',
     'SQL/Parser.pm' => sub {
         _glob_in_inc('SQL/Dialects', 1);
     },
@@ -1221,33 +1241,40 @@ sub _compile_or_execute {
     my ($feed_fh, $feed_file) = File::Temp::tempfile();
     my $dump_file = "$feed_file.out";
 
+    require Data::Dumper;
+
+    # spoof $0 (to $file) so that FindBin works as expected
+    # NOTE: We don't directly assign to $0 as it has magic (i.e.
+    # assigning has side effects and may actually fail, cf. perlvar(1)).
+    # Instead we alias *0 to a package variable holding the correct value.
+    print $feed_fh "BEGIN { ", 
+                   Data::Dumper->Dump([ $file ], [ "Module::ScanDeps::DataFeed::_0" ]),
+                   "*0 = \\\$Module::ScanDeps::DataFeed::_0; }\n";
+
     print $feed_fh $do_compile ? "INIT {\n" : "END {\n";
     # NOTE: When compiling the block will run _after_ all CHECK blocks
     # (but _before_ the first INIT block) and will terminate the program.
     # When executing the block will run as the first END block and 
     # the programs continues.
 
-    # correctly escape filenames
-    require Data::Dumper;
+    # correctly escape strings containing filenames
     print $feed_fh map { "my $_" } Data::Dumper->Dump(
-                     [ $INC{"Module/ScanDeps/DataFeed.pm"}, $dump_file],
-                     [qw( datafeedpm dump_file )]);
+                       [ $INC{"Module/ScanDeps/DataFeed.pm"}, $dump_file ],
+                       [ qw( datafeedpm dump_file ) ]);
 
     print $feed_fh <<'...';
-    # localize %INC etc so that the folllowing require doesn't pollute them
-    {
-        local %INC = %INC;
-        local @INC = @INC;
-        local @DynaLoader::dl_shared_objects = @DynaLoader::dl_shared_objects;
-        local @DynaLoader::dl_modules = @DynaLoader::dl_modules;
+    # save %INC etc so that further requires dont't pollute them
+    %Module::ScanDeps::DataFeed::_INC = %INC;
+    @Module::ScanDeps::DataFeed::_INC = @INC;
+    @Module::ScanDeps::DataFeed::_dl_shared_objects = @DynaLoader::dl_shared_objects;
+    @Module::ScanDeps::DataFeed::_dl_modules = @DynaLoader::dl_modules;
 
         require $datafeedpm;
-    }
 
     Module::ScanDeps::DataFeed::_dump_info($dump_file);
 ...
 
-    print $feed_fh $do_compile ? "exit(0); }\n" : "}\n";
+    print $feed_fh $do_compile ? "exit(0);\n}\n" : "}\n";
 
     # append the file to compile
     {
